#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 language-c99-simple
version:              0.3.0
visibility:           public
id:                   language-c99-simple-0.3.0-1kUH0hiju10LsINxHPVIpN
key:                  language-c99-simple-0.3.0-1kUH0hiju10LsINxHPVIpN
license:              MIT
maintainer:           Frank Dedden <dev@dedden.net>
author:               Frank Dedden
synopsis:             C-like AST to simplify writing C99 programs.
description:
    This package is a wrapper on top of '\''language-c99'\''. It provides a simpler
    interface more suited for writing C99 programs. It achieves this by
    implementing its own C-like AST, supporting the most used C features. In
    turn, this AST is translated into actual C99 one, showing that it is an
    actual subset.

category:             Language
abi:                  5d1b97e56536b7da65a0d5346b9b5e34
exposed:              True
exposed-modules:
    Language.C99.Simple Language.C99.Simple.AST
    Language.C99.Simple.Expr Language.C99.Simple.Translate
    Language.C99.Simple.Util

import-dirs:          /usr/lib/ghc-9.6.6/site-local/language-c99-simple-0.3.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/language-c99-simple-0.3.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/language-c99-simple-0.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-language-c99-simple
hs-libraries:         HSlanguage-c99-simple-0.3.0-1kUH0hiju10LsINxHPVIpN
depends:
    base-4.18.2.1 language-c99-0.2.0-I4UDScyYKGbBkxhpHP0xVR
    language-c99-util-0.2.0-6rt8W6b4a2wqMXtuB2WFg mtl-2.3.1

haddock-interfaces:
    /usr/share/doc/haskell-language-c99-simple/html/language-c99-simple.haddock

haddock-html:         /usr/share/doc/haskell-language-c99-simple/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

